@@ -4,10 +4,10 @@
 #' is obtained by the original data multiplied by the dimension reduction directions of given
 #' dimension.
 #'
-#' @param dr the object returned by \code{\link{mave}} or \code{\link{mave.dim}}
+#' @param dr the object returned by \code{\link[MAVE]{mave}} or \code{\link[MAVE]{mave.dim}}
 #' @param x the original data matrix of p dimensions
 #' @param dim the dimension of the reduced data matrix.
-#' @seealso \code{\link{coef.mave}} for obtaining the dimension reduction directions
+#' @seealso \code{\link[MAVE]{coef.mave}} for obtaining the dimension reduction directions
 #' @export
 #' @examples
 #'
@@ -18,7 +18,7 @@
 
 mave.data<-function(dr, x, dim = NULL){
 
-  if(class(dr)=='mave'){
+  if(inherits(dr, 'mave')){
     if(!is.null(dim)){
       if(dim<=dr$max.dim){
          return(as.matrix(x%*%coef.mave(dr,dim)))
@@ -33,7 +33,7 @@ mave.data<-function(dr, x, dim = NULL){
       stop('dim should be given.')
     }
   }
-  if(class(dr)=='mave.dim'){
+  if(inherits(dr, 'mave.dim')){
     if(is.null(dim)){
       return(as.matrix(x%*%coef.mave.dim(dr)))
     }
