@@ -22,22 +22,22 @@ void quantile(const emxArray_real_T *x, const emxArray_real_T *p,
               emxArray_real_T *y)
 {
   emxArray_real_T *p100;
-  int i2;
+  int i9;
   double delta;
   int loop_ub;
-  emxInit_real_T(&p100, 2);
+  emxInit_real_T1(&p100, 2);
   if ((p->size[1] == 1) && (p->data[0] == std::floor(p->data[0])) && (p->data[0]
        > 1.0)) {
     delta = 100.0 / (p->data[0] + 1.0);
     linspace(delta, 100.0 - delta, p->data[0], p100);
   } else {
-    i2 = p100->size[0] * p100->size[1];
+    i9 = p100->size[0] * p100->size[1];
     p100->size[0] = 1;
     p100->size[1] = p->size[1];
-    emxEnsureCapacity((emxArray__common *)p100, i2, (int)sizeof(double));
+    emxEnsureCapacity((emxArray__common *)p100, i9, sizeof(double));
     loop_ub = p->size[0] * p->size[1];
-    for (i2 = 0; i2 < loop_ub; i2++) {
-      p100->data[i2] = 100.0 * p->data[i2];
+    for (i9 = 0; i9 < loop_ub; i9++) {
+      p100->data[i9] = 100.0 * p->data[i9];
     }
   }
 
