@@ -17,49 +17,6 @@
 
 /* Function Definitions */
 void b_repmat(const emxArray_real_T *a, double varargin_2, emxArray_real_T *b)
-{
-  int outsize_idx_0;
-  int outsize_idx_1;
-  int jtilecol;
-  boolean_T p;
-  int ibtile;
-  int jcol;
-  int iacol;
-  int ibmat;
-  int k;
-  outsize_idx_0 = a->size[0];
-  outsize_idx_1 = a->size[1] * (int)varargin_2;
-  jtilecol = b->size[0] * b->size[1];
-  b->size[0] = outsize_idx_0;
-  b->size[1] = outsize_idx_1;
-  emxEnsureCapacity((emxArray__common *)b, jtilecol, (int)sizeof(double));
-  if (!((a->size[0] == 0) || (a->size[1] == 0))) {
-    if (outsize_idx_0 == 0) {
-      p = true;
-    } else if (outsize_idx_1 == 0) {
-      p = true;
-    } else {
-      p = false;
-    }
-
-    if (!p) {
-      outsize_idx_0 = a->size[0];
-      outsize_idx_1 = a->size[1];
-      for (jtilecol = 1; jtilecol <= (int)varargin_2; jtilecol++) {
-        ibtile = (jtilecol - 1) * (outsize_idx_0 * outsize_idx_1) - 1;
-        for (jcol = 0; jcol + 1 <= outsize_idx_1; jcol++) {
-          iacol = jcol * outsize_idx_0;
-          ibmat = ibtile + jcol * outsize_idx_0;
-          for (k = 1; k <= outsize_idx_0; k++) {
-            b->data[ibmat + k] = a->data[(iacol + k) - 1];
-          }
-        }
-      }
-    }
-  }
-}
-
-void c_repmat(const emxArray_real_T *a, double varargin_2, emxArray_real_T *b)
 {
   int outsize_idx_0;
   int jtilecol;
@@ -70,7 +27,7 @@ void c_repmat(const emxArray_real_T *a, double varargin_2, emxArray_real_T *b)
   jtilecol = b->size[0] * b->size[1];
   b->size[0] = outsize_idx_0;
   b->size[1] = (int)varargin_2;
-  emxEnsureCapacity((emxArray__common *)b, jtilecol, (int)sizeof(double));
+  emxEnsureCapacity((emxArray__common *)b, jtilecol, sizeof(double));
   if (!(a->size[0] == 0)) {
     if (outsize_idx_0 == 0) {
       p = true;
@@ -84,8 +41,8 @@ void c_repmat(const emxArray_real_T *a, double varargin_2, emxArray_real_T *b)
       outsize_idx_0 = a->size[0];
       for (jtilecol = 1; jtilecol <= (int)varargin_2; jtilecol++) {
         ibtile = (jtilecol - 1) * outsize_idx_0;
-        for (k = 1; k <= outsize_idx_0; k++) {
-          b->data[(ibtile + k) - 1] = a->data[k - 1];
+        for (k = 0; k + 1 <= outsize_idx_0; k++) {
+          b->data[ibtile + k] = a->data[k];
         }
       }
     }
@@ -102,7 +59,7 @@ void repmat(const emxArray_real_T *a, double varargin_1, emxArray_real_T *b)
   ibmat = b->size[0] * b->size[1];
   b->size[0] = (int)varargin_1;
   b->size[1] = outsize_idx_1;
-  emxEnsureCapacity((emxArray__common *)b, ibmat, (int)sizeof(double));
+  emxEnsureCapacity((emxArray__common *)b, ibmat, sizeof(double));
   if (!(a->size[1] == 0)) {
     if ((int)varargin_1 == 0) {
       p = true;
